@@ -1,5 +1,3 @@
-/* $Id: signal.h,v 1.4 1999/02/23 11:43:18 martin Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -30,7 +28,7 @@
 #include <sys/signal.h>
 #endif
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 typedef struct _glibtop_signame	glibtop_signame;
 
@@ -42,6 +40,6 @@ struct _glibtop_signame
 
 extern const glibtop_signame glibtop_sys_siglist [];
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
