@@ -35,7 +35,7 @@ static const unsigned long _glibtop_sysdeps_msg_limits =
 /* Init function. */
 
 void
-glibtop_init_msg_limits_s (glibtop *server)
+_glibtop_init_msg_limits_s (glibtop *server)
 {
 	server->sysdeps.msg_limits = _glibtop_sysdeps_msg_limits;
 }
